pub enum ShutdownMode {
Graceful,
Immediate,
}Expand description
Determines how to shut down the Relay system.
To initiate a shutdown, use Controller::shutdown.
Variants
Graceful
Shut down gracefully within the configured timeout.
This will signal all components to finish their work and leaves time to submit pending data to the upstream or preserve it for restart.
Immediate
Shut down immediately without finishing pending work.
Pending data may be lost.