pub struct Builder { /* private fields */ }Expand description
Configures a Relay Runtime.
Implementations
Sourceimpl Builder
impl Builder
Sourcepub fn worker_threads(&mut self, num: usize) -> &mut Self
pub fn worker_threads(&mut self, num: usize) -> &mut Self
Configures the amount of worker threads available to the runtime.
The default value is the number of cores available to the system.
See also: [tokio::runtime::Builder::worker_threads].
Sourcepub fn max_blocking_threads(&mut self, num: usize) -> &mut Self
pub fn max_blocking_threads(&mut self, num: usize) -> &mut Self
Configures the amount of threads in the dynamic thread pool of the runtime.
See also: [tokio::runtime::Builder::max_blocking_threads].
Sourcepub fn thread_keep_alive(&mut self, duration: Duration) -> &mut Self
pub fn thread_keep_alive(&mut self, duration: Duration) -> &mut Self
Configures the idle timeout of threads in the dynamic thread pool.
See also: [tokio::runtime::Builder::thread_keep_alive].