pub struct Handle { /* private fields */ }Expand description
Handle to the Runtime.
The handle is internally reference-counted and can be freely cloned.
A handle can be obtained using the Runtime::handle method.
Implementations
Sourceimpl Handle
impl Handle
Sourcepub fn metrics(&self) -> RuntimeMetrics
pub fn metrics(&self) -> RuntimeMetrics
Returns a new RuntimeMetrics handle for this runtime.
Sourcepub fn current_services_metrics(&self) -> ServicesMetrics
pub fn current_services_metrics(&self) -> ServicesMetrics
Returns all service metrics of all currently running services.
Unlike Self::metrics, this is not a handle to the metrics.
Sourcepub fn service_set(&self) -> ServiceSet
pub fn service_set(&self) -> ServiceSet
Returns a new unique ServiceSet to spawn services and await their termination.