pub struct Recipient<M, R> { /* private fields */ }Expand description
An address to a Service implementing any interface that takes a given message.
This is similar to an Addr, but it is bound to a single message rather than an interface. As
such, this type is not meant for communicating with a service implementation, but rather as a
handle to any service that can consume a given message. These can be back-channels or hooks that
are configured externally through Inversion of Control (IoC).
Recipients are created through Addr::recipient.
Implementations
Sourceimpl<M, R> Recipient<M, R>where
R: MessageResponse,
impl<M, R> Recipient<M, R>where
R: MessageResponse,