pub struct Sender<T>(/* private fields */);Expand description
Sends a message response from a service back to the waiting Request.
The sender is part of an AsyncResponse and should be moved into the service interface
type. If this sender is dropped without calling send, the request fails with
SendError.
Implementations