pub struct ServicesMetrics(/* private fields */);Expand description
A point in time snapshot of all started services and their ServiceMetrics.
Implementations
Sourceimpl ServicesMetrics
impl ServicesMetrics
Sourcepub fn iter(&self) -> impl Iterator<Item = (ServiceId, ServiceMetrics)> + '_
pub fn iter(&self) -> impl Iterator<Item = (ServiceId, ServiceMetrics)> + '_
Returns an iterator of all service identifiers and their ServiceMetrics.