pub trait LoadShed<T> {
// Required method
fn handle_loadshed(&self, _message: T);
}Expand description
A trait describing what to do with a message that was load-shed.
Required Methods
Sourcefn handle_loadshed(&self, _message: T)
fn handle_loadshed(&self, _message: T)
Gets called for every message that gets dropped by loadshedding.