ServiceSpawn

Trait ServiceSpawn 

pub trait ServiceSpawn {
    // Required method
    fn start_obj(&self, service: ServiceObj);
}
The ServiceSpawn trait allows for starting a Service on an executor that will run them to completion.

Often you want to spawn your service directly via ServiceSpawnExt.

Required Methods

fn start_obj(&self, service: ServiceObj)

Starts the service on the executor.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl ServiceSpawn for Handle

Source

impl ServiceSpawn for ServiceSet

Source

impl ServiceSpawn for TokioServiceSpawn

Available on crate feature test only.